@@ -9,10 +9,9 @@ import nose
 from fabric.api import *
 
 import docs, tag
-from utils import msg
 
 
-@task
+@task(default=True)
 def test(args=None):
     """
     Run all unit tests and doctests.
@@ -32,8 +31,7 @@ def upload():
     """
     Build, register and upload to PyPI
     """
-    with msg("Uploading to PyPI"):
-        local('python setup.py sdist register upload')
+    local('python setup.py sdist register upload')
 
 
 @task
