@@ -116,11 +116,16 @@ def is_classic_task(tup):
     Takes (name, object) tuple, returns True if it's a non-Fab public callable.
     """
     name, func = tup
-    return (
-        callable(func)
-        and (func not in _internals)
-        and not name.startswith('_')
-    )
+    try:
+        is_classic = (
+            callable(func)
+            and (func not in _internals)
+            and not name.startswith('_')
+        )
+    # Handle poorly behaved __eq__ implementations
+    except (ValueError, TypeError):
+        is_classic = False
+    return is_classic
 
 
 def load_fabfile(path, importer=None):
@@ -370,8 +375,12 @@ def crawl(name, mapping):
     try:
         result = _crawl(name, mapping)
         # Handle default tasks
-        if isinstance(result, _Dict) and getattr(result, 'default', False):
-            result = result.default
+        if isinstance(result, _Dict):
+            if getattr(result, 'default', False):
+                result = result.default
+            # Ensure task modules w/ no default are treated as bad targets
+            else:
+                result = None
         return result
     except (KeyError, TypeError):
         return None
@@ -516,8 +525,9 @@ def parse_arguments(arguments):
         if ':' in cmd:
             cmd, argstr = cmd.split(':', 1)
             for pair in _escape_split(',', argstr):
-                k, _, v = pair.partition('=')
-                if _:
+                result = _escape_split('=', pair)
+                if len(result) > 1:
+                    k, v = result
                     # Catch, interpret host/hosts/role/roles/exclude_hosts
                     # kwargs
                     if k in ['host', 'hosts', 'role', 'roles', 'exclude_hosts']:
@@ -535,7 +545,7 @@ def parse_arguments(arguments):
                     else:
                         kwargs[k] = v
                 else:
-                    args.append(k)
+                    args.append(result[0])
         cmds.append((cmd, args, kwargs, hosts, roles, exclude_hosts))
     return cmds
 
@@ -677,6 +687,7 @@ Remember that -f can be used to specify fabfile path, and use -h for help.""")
         # Load fabfile (which calls its module-level code, including
         # tweaks to env values) and put its commands in the shared commands
         # dict
+        default = None
         if fabfile:
             docstring, callables, default = load_fabfile(fabfile)
             state.commands.update(callables)
